Module screen

Module screen 

Brain screen display and touch functions.

Contains user calls to the v5 screen for touching and displaying graphics.

Structs

screen_touch_status_s_t
Struct representing screen touch status, screen last x, screen last y, press count, release count.

Constants

E_TEXT_LARGE
E_TEXT_LARGE_CENTER
E_TEXT_MEDIUM
E_TEXT_MEDIUM_CENTER
E_TEXT_SMALL
E_TOUCH_ERROR
E_TOUCH_HELD
E_TOUCH_PRESSED
E_TOUCH_RELEASED

Functions

display_fatal_error
Display a fatal error to the built-in LCD/touch screen.
screen_copy_area
Copy a screen region (designated by a rectangle) from an off-screen buffer to the screen
screen_draw_circle
Draw a circle on the screen using the current pen color
screen_draw_line
Draw a line on the screen using the current pen color
screen_draw_pixel
Draw a single pixel on the screen using the current pen color
screen_draw_rect
Draw a rectangle on the screen using the current pen color
screen_erase
Clear display with eraser color
screen_erase_circle
Erase a circle on the screen using the current eraser color
screen_erase_line
Erase a line on the screen using the current eraser color
screen_erase_pixel
Erase a pixel from the screen (Sets the location)
screen_erase_rect
Erase a rectangle on the screen using the current eraser color
screen_fill_circle
Fill a circular region of the screen using the current pen color
screen_fill_rect
Fill a rectangular region of the screen using the current pen color
screen_get_eraser
Get the current eraser color.
screen_get_pen
Get the current pen color.
screen_print
Print a formatted string to the screen on the specified line
screen_print_at
Print a formatted string to the screen at the specified point
screen_scroll
Scroll lines on the display upwards.
screen_scroll_area
Scroll lines within a region on the display
screen_set_eraser
Set the eraser color for erasing and the current background.
screen_set_pen
Set the pen color for subsequent graphics operations
screen_touch_callback
Assigns a callback function to be called when a certain touch event happens.
screen_touch_status
Gets the touch status of the last touch of the screen.
screen_vprintf
Print a formatted string to the screen on the specified line

Type Aliases

last_touch_e_t
text_format_e_t
touch_event_cb_fn_t