pub unsafe extern "C" fn screen_draw_circle(
x: i16,
y: i16,
radius: i16,
) -> u32Expand description
Draw a circle on the screen using the current pen color
This function uses the following values of errno when an error state is reached: EACCESS - Another resource is currently trying to access the screen mutex.
\param x, y The (x,y) coordinates of the center of the circle \param r The radius of the circle
\return 1 if there were no errors, or PROS_ERR if an error occured taking or returning the screen mutex.